        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 20 <strong>control</strong><br>0,1,3,6,8,13,15,16,21,26,27,28,31,32,34,40,43,45,47,49';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 18 <br>4,11,12,17,19,24,25,29,33,35,36,37,38,39,41,44,46,50';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 13 <br>2,5,7,9,10,14,18,20,22,23,30,42,48';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 20 <strong>control</strong><br>0,1,3,6,8,13,15,16,21,26,27,28,31,32,34,40,43,45,47,49';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 18 <br>4,11,12,17,19,24,25,29,33,35,36,37,38,39,41,44,46,50';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 13 <br>2,5,7,9,10,14,18,20,22,23,30,42,48';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 20 <strong>control</strong><br>0,1,3,6,8,13,15,16,21,26,27,28,31,32,34,40,43,45,47,49';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 18 <br>4,11,12,17,19,24,25,29,33,35,36,37,38,39,41,44,46,50';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 13 <br>2,5,7,9,10,14,18,20,22,23,30,42,48';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 20 <strong>control</strong><br>0,1,3,6,8,13,15,16,21,26,27,28,31,32,34,40,43,45,47,49';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 18 <br>4,11,12,17,19,24,25,29,33,35,36,37,38,39,41,44,46,50';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 13 <br>2,5,7,9,10,14,18,20,22,23,30,42,48';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 20 <strong>control</strong><br>0,1,3,6,8,13,15,16,21,26,27,28,31,32,34,40,43,45,47,49';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 18 <br>4,11,12,17,19,24,25,29,33,35,36,37,38,39,41,44,46,50';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260505 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 13 <br>2,5,7,9,10,14,18,20,22,23,30,42,48';}
}
